@@ -41,5 +41,9 @@ def _f_expl_2_heun(x0, Y0, dx, *args, dYdx=None, **kwargs):
     return dx*(b0*k0 + b1*k1)
 
 
-expl_2_heun = Scheme(
-    _f_expl_2_heun, description="Explicit 2nd-order Heun's method")
+class expl_2_heun(Scheme):
+    """Class for explicit 2nd-order Heun's method"""
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(_f_expl_2_heun,
+                         description="Explicit 2nd-order Heun's method", *args, **kwargs)
